@@ -111,7 +111,7 @@ static double distance(
   unsigned int swapCount, targetCharCount,i,j;
   double delScore, insScore, subScore, swapScore;
   unsigned int score_ceil = x + y;
-  double colmin;
+  
   /* intialize matrix start values */
   scores[0] = score_ceil;  
   scores[1 * (y + 2) + 0] = score_ceil;
@@ -128,7 +128,7 @@ static double distance(
     scores[(i+1) * (y + 2) + 1] = i;
     scores[(i+1) * (y + 2) + 0] = score_ceil;
     swapCount = 0;
-    colmin = (double) x + y + 1;
+    
     for(j=1;j<=y;j++){
       if(i == 1) {
         uniquePush(dict,tgt[j]);
@@ -146,25 +146,17 @@ static double distance(
       } else {
         swapCount = j;
         scores[(i+1) * (y + 2) + (j + 1)] = min2(scores[i * (y + 2) + j], swapScore);
-      } 
-      colmin = min2(colmin,scores[(i+1)*(y+2) + (j+1)]);
+      }
     }
     /* We will return -1 here if the */
     /* current minimum > maxDistance   */
-    if(maxDistance > 0 && maxDistance < colmin) {
-
-      reset_dictionary(dict);
-      return -1;
-    }
 
       dict->value[which(dict,src[i-1])] = i;    
   }
 
-  {
   double score = scores[(x+1) * (y + 2) + (y + 1)];
   reset_dictionary(dict);
-  return score;
-  }
+  return (maxDistance > 0 && maxDistance < score) ? (-1) : score;
 }
 
 /* End of workhorse */
